@@ -1,4 +1,5 @@
 import os
+import json
 import streamlit.components.v1 as components
 from typing import ( Optional, 
     Union, List )
@@ -10,11 +11,11 @@ _RELEASE = True
 if not _RELEASE:
     _component_func_command = components.declare_component(
         "command",
-        url="http://localhost:3001",
+        url="http://localhost:3002",
     )
     _component_func_get = components.declare_component(
         "get",
-        url="http://localhost:3002",
+        url="http://localhost:3001",
     )
     _component_func_send = components.declare_component(
         "set",
@@ -29,16 +30,16 @@ else:
     build_dir = os.path.join(parent_dir, "send")
     _component_func_send = components.declare_component("send", path=build_dir)
 
-def command(commandString: str, 
-    commandOptions: Optional[str] = "", 
+def command(command_string: str, 
+    command_options: Optional[str] = "", 
     key: str = None) -> str:
     """Create a new instance of "button.command".
 
     Parameters
     ----------
-    commandString: str
+    command_string: str
         Name of the command or a command macro. E.g. 'PO_AddRooms' OR '_Line 0,0,0 2,2,2'.
-    commandOptions: str
+    command_options: str
         WIP.
     key: str or None
         An optional key that uniquely identifies this component. If this is
@@ -51,23 +52,27 @@ def command(commandString: str,
         If the command run successfully it is the name of the command.
 
     """
-    component_value = _component_func_command(commandString=commandString, 
-        commandOptions=commandOptions,
+    component_value = _component_func_command(command_string=command_string, 
+        command_options=command_options,
         key=key, 
         default=None)
     return component_value
 
-def get(isPollinationModel: Optional[bool] = False, 
-    syncToken: Optional[str] = "",
+def get(
+    is_pollination_model: Optional[bool] = False, 
+    button_text: Optional[str] = "",
+    sync_token: Optional[str] = "",
     key : str = None,
-    platform: str = 'rhino') -> str:
+    platform: str = "rhino") -> str:
     """Create a new instance of "button.get".
 
     Parameters
     ----------
-    isPollinationModel: bool
+    is_pollination_model: bool
         True if you want to send a HBJson. False if you send geometries.
-    syncToken: str
+    button_text: str
+        Button text to display.
+    sync_token: str
         A special string that enable the auto-refresh of the component. 
         Connect the return of the special.sync component.
     key: str or None
@@ -76,23 +81,26 @@ def get(isPollinationModel: Optional[bool] = False,
         be re-mounted in the Streamlit frontend and lose its current state.
     platform: str
         A key that uniquely identifies the host software. 
-        Supported values: rhino, sketchup. Default value is rhino.
+        Supported values: rhino, sketchup. Default value is rhino. 
+        revit is WIP.
     Returns
     -------
     string
         Ladybug geometry JSON array string which comes from Rhino.
     """
-    component_value = _component_func_get(isPollinationModel=isPollinationModel, 
-        syncToken=syncToken,
+    component_value = _component_func_get(
+        is_pollination_model=is_pollination_model, 
+        button_text=button_text,
+        sync_token=sync_token,
         key=key, 
-        default=None,
-        platform=platform)
+        platform=platform,
+        default=None)
 
     return component_value
 
 def send(action: str, 
     data: Union[dict, List[dict]], 
-    uniqueId: str, 
+    unique_id: str, 
     options: Optional[dict] = {},
     key: str = None,
     platform: str = 'rhino') -> str:
@@ -107,11 +115,12 @@ def send(action: str,
         - DrawGeometry
         - DisableDraw
         - BakePollinationModel
-        - SaveResults
+        - AddResults
+        - ClearResults
     
     data: dict or List[dict]
         A ladybug geometry dictionary or a list of ladybug geometry dictionary.
-    uniqueId: str
+    unique_id: str
         A key to recognize what geometries come from streamlit on Rhino. It becomes 
         a userString inside Rhino.
     options: dict
@@ -140,7 +149,7 @@ def send(action: str,
     """
     component_value = _component_func_send(action=action, 
         data=data,
-        uniqueId=uniqueId,
+        unique_id=unique_id,
         options=options,
         key=key, 
         default="NAN",
@@ -152,10 +161,16 @@ if not _RELEASE:
     import streamlit as st
     import json
 
+    host_software = st.selectbox(
+     "Host software?",
+     ("rhino", "sketchup", "revit"))
+
+    print(host_software)
+
     st.subheader("Component with constant args")
 
     name_input = st.text_input("Enter the command here!", value="PO_AddRooms")
-    c_btn_value = command(commandString=name_input, key="secret-key-1")
+    c_btn_value = command(command_string=name_input, key="secret-key-1")
     st.write(c_btn_value)
 
     st.subheader("Pollination, Bake Geometry Button")
@@ -168,46 +183,55 @@ if not _RELEASE:
         }, 
         { 
             'type': 'Polyline2D',
-             'vertices': [[0, 0], [10, 0], [0, 10]] 
+             'vertices': [[0, 0], [10, 0], [0, 10]],
+             'color': {"r": 255, "g": 0, "b": 0}
         }]
 
     option = st.selectbox(
      "What command do you want to use?",
      ("BakeGeometry", "ClearGeometry", "DrawGeometry", 
-        "DisableDraw", "SaveResults"))
+        "DisableDraw", "AddResults", "ClearResults"))
     
     command_active = send(
         action=option,
         data=data_to_pass, 
-        uniqueId="my-secret-key", 
+        unique_id="my-secret-key", 
         options={
             "layer": "MyCustomLayer", 
             "units": "Feet"
             },
-        key="secret-key-2")
+        key="secret-key-2",
+        platform=host_software)
     
     st.write("Command in action: %s !" % command_active)
     st.write(data_to_pass)
 
     st.subheader("Pollination, Get Geometry Button")
-    geometry = get(key="secret-key-4", platform="sketchup")
+    geometry = get(key="secret-key-4", 
+        platform=host_software)
+    st.write(geometry)
     if geometry:
-        st.write(json.loads(geometry))
+        command_active = send(
+            action="BakeGeometry",
+            data=geometry, 
+            unique_id="my-secret-key-5", 
+            options={
+                "layer": "MyCustomLayer", 
+                "units": "Meters"
+                },
+            key="secret-key-5",
+            platform=host_software)
 
-    host_software = st.selectbox(
-     "Host software?",
-     ("rhino", "sketchup"))
 
-    print(host_software)
     st.subheader("Pollination, Get/Send Pollination Model Button")
-    model = get(isPollinationModel=True, 
-        key="secret-key-5", 
+    model = get(is_pollination_model=True, 
+        key="secret-key-6", 
+        button_text="OSM Model",
         platform=host_software)
     if model:
-        json_model = json.loads(model)
-        st.write(json_model)
-    if model and host_software == "rhino":
         command_model = send("BakePollinationModel",
-            json_model, "my-secret-key", key="secret-key-3")
+            model, "my-secret-key", 
+            key="secret-key-7",
+            platform=host_software)
 
     
\ No newline at end of file
